summaryrefslogtreecommitdiffhomepage
path: root/pkg/sentry/fs/mount.go
diff options
context:
space:
mode:
Diffstat (limited to 'pkg/sentry/fs/mount.go')
-rw-r--r--pkg/sentry/fs/mount.go11
1 files changed, 7 insertions, 4 deletions
diff --git a/pkg/sentry/fs/mount.go b/pkg/sentry/fs/mount.go
index a169ea4c9..9740f1fc6 100644
--- a/pkg/sentry/fs/mount.go
+++ b/pkg/sentry/fs/mount.go
@@ -110,9 +110,8 @@ type MountSource struct {
// MountSourceOperations defines filesystem specific behavior.
MountSourceOperations
- // Filesystem is the filesystem backing the mount. Can be nil if there
- // is no filesystem backing the mount.
- Filesystem Filesystem
+ // FilesystemType is the type of the filesystem backing this mount.
+ FilesystemType string
// Flags are the flags that this filesystem was mounted with.
Flags MountSourceFlags
@@ -158,10 +157,14 @@ const DefaultDirentCacheSize uint64 = 1000
// NewMountSource returns a new MountSource. Filesystem may be nil if there is no
// filesystem backing the mount.
func NewMountSource(mops MountSourceOperations, filesystem Filesystem, flags MountSourceFlags) *MountSource {
+ fsType := "none"
+ if filesystem != nil {
+ fsType = filesystem.Name()
+ }
return &MountSource{
MountSourceOperations: mops,
Flags: flags,
- Filesystem: filesystem,
+ FilesystemType: fsType,
fscache: NewDirentCache(DefaultDirentCacheSize),
children: make(map[*MountSource]struct{}),
}